@@ -35,16 +35,7 @@ for dataset in datasets:
     print(
         f"Retrieve raw data in dataset: {raw_dataset.name} - version: {raw_dataset.version}"
     )
-    #if number_chunk == 1:
-    chunk_name = "chunk0"
-    if dataset_directory is None or dataset_directory == "":
-        dir_path = Path(str(Path(raw_data_dir) / chunk_name))
-    else:
-        dir_path = Path(str(Path(raw_data_dir) / chunk_name / dataset_directory))
-    dir_path.mkdir(parents=True, exist_ok=True)
-    dataset.download(target_path=dir_path, overwrite=False)
-#else:
-    #    raw_dataset.as_mount("/mnt/input_data")
-    #    chunk_files(raw_dataset, raw_data_dir, number_chunk, shutil.copy, [chunk_index], dataset_directory)
+    raw_dataset.as_mount("/mnt/input_data")
+    chunk_files(raw_dataset, raw_data_dir, number_chunk, shutil.copy, [chunk_index], dataset_directory)
 
 
